import React, { useState } from "react";
import { Form, Input, Button, Tabs, message } from "antd";
import styles from "./login.module.css";
import { login } from "../../http/sso";
import GonganIcon from "@src/assets/images/login/gongan.png";

const LoginPage: React.FC = () => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);

  const handlePhoneLogin = async (values: any) => {
    try {
      setLoading(true);
      const { phone, password } = values;
      const success = await login(phone, password);
      if (success) {
        // Redirect will be handled by the login function
      }
    } catch (error) {
      message.error((error as Error)?.message || "登录失败，请重试");
    } finally {
      setLoading(false);
    }
  };

  return (
    <div className={styles.loginContainer}>
      <div className={styles.decorationTop}>
        <div>
          <div className={styles.leftSection}>
            <div className={styles.platformTitle}>票圈安全平台</div>
          </div>
          <div className={styles.rightSection}>
            <div className={styles.loginBox}>
              <div className={styles.tabsContainer}>
                <Tabs
                  defaultActiveKey="account"
                  items={[
                    {
                      key: "account",
                      label: "账号登录",
                      children: (
                        <Form
                          form={form}
                          onFinish={handlePhoneLogin}
                          layout="vertical"
                          size="large"
                        >
                          <Form.Item
                            name="phone"
                            rules={[{
                              required: true,
                              message: "请输入手机号",
                            }, {
                              pattern: /^1[3-9]\d{9}$/,
                              message: "请输入正确的手机号",
                            }]}
                          >
                            <Input
                              variant="borderless"
                              addonBefore={
                                <div className={ styles.phonePrefix }>
                                  +86
                                </div>
                              }
                              placeholder="手机号"
                              className={
                                styles.phoneInput + " border-b-[1px] border-b-gray-400"
                              }
                            />
                          </Form.Item>

                          <Form.Item
                            name="password"
                            rules={[{
                                required: true,
                                message: "请输入密码",
                            }]}
                          >
                            <Input.Password
                              placeholder="密码"
                              variant="borderless"
                              className="!rounded-none !border-b-[1px] !border-b-gray-400"
                            />
                          </Form.Item>

                          <Form.Item>
                            <Button
                              type="primary"
                              htmlType="submit"
                              block
                              loading={loading}
                              className={styles.loginBtn}
                            >
                              登录
                            </Button>
                          </Form.Item>
                        </Form>
                      ),
                    },
                  ]}
                />
              </div>
            </div>
          </div>
        </div>
      </div>

      <div className={styles.decorationBottom}>
        {/* You can add a decoration image here */}
        <p>© 2020 湖南为趣时代网络科技有限公司</p>
        <p>
          <span className="link cursor-pointer" onClick={() => window.open('https://rescdn.yishihui.com/agreement/piaoquantvservice.html')}>
            用户服务协议 
          </span>
          <span className="mx-1">|</span>
          <span className="link cursor-pointer" onClick={() => window.open('https://rescdn.yishihui.com/agreement/piaoquantvagreement.html')}>
            隐私政策 
          </span>
          <span className="mx-1">|</span>
          <span className="link cursor-pointer" onClick={() => window.open('https://www.piaoquantv.com/upload/help')}>
            帮助中心 
          </span>
          <span className="mx-1">|</span>
          客服及举报: 0731-85679198、18974809627
          <span className="mx-1">|</span>
          举报邮箱：piaoquankefu@new.piaoquantv.com
        </p>

        <p className="flex items-center justify-center">
          <span className="link cursor-pointer" onClick={() => window.open('https://beian.miit.gov.cn/')}>
            湘ICP备16013107-06号
          </span>
          | <img style={{ width: '16px', height: '16px' }} src={GonganIcon} />
          <span className="link cursor-pointer" onClick={() => window.open('https://beian.mps.gov.cn/#/query/webSearch')}>
            湘公网安备：43019002001624
          </span>
        </p>
      </div>
    </div>
  );
};

export default LoginPage;
